@@ -4,7 +4,7 @@
 modname = 'trackervcs'
 distname = 'cubicweb-trackervcs'
 
-numversion = (0, 3, 0)
+numversion = (0, 4, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -14,7 +14,7 @@ description = 'vcsfile / tracker integration'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {'cubicweb': '>= 3.10.0',
-               'cubicweb-vcreview': None,
+               'cubicweb-vcreview': '>= 0.4.0',
                'cubicweb-tracker': None,
                }
 
